@@ -2,7 +2,7 @@
  * 
  * Copyright 1992-1998 Werner Almesberger
  * Copyright 1999-2005 John Coffman
- * Copyright 2009-2013 Joachim Wiedorn
+ * Copyright 2009-2014 Joachim Wiedorn
  * All rights reserved.
  * 
  * Licensed under the terms contained in the file 'COPYING'
@@ -226,11 +226,10 @@ void part_verify(int dev_nr,int type)
 	dos ? "  A DOS/Windows system may be rendered unbootable."
 		"\n  The backup copy of this boot sector should be retained."
 		: "" );
+	fprintf (errstd, "I will assume that you know what you're doing and I will proceed.\n");
 #if 0
 	if (!dos && !cfg_get_flag(cf_options,"ignore-table"))
 	    die("You may proceed by using either '-P ignore' or 'ignore-table'");
-#else
-	if (!yesno("\nProceed? ", 0)) exit(0);
 #endif
     }
     cyl = part_table[part].cyl+((part_table[part].sector >> 6) << 8);
